## Modules
 - `snake_big` - contains Snake class: the gym environment with a big grid_size $^2$ - element observation space
 - `snake_small` - contains Snake class: the gym environment with a small 4-element observation space, works better for big grids (>7 length)